@@ -62,9 +62,11 @@ function ParaseleneWindowSize(){
 
 	this.height=paraselene_min(window.innerHeight,document.body.clientHeight);
 	this.height=paraselene_min(this.height,document.documentElement.clientHeight);
+	this.height=paraselene_min(this.height,document.body.scrollHeight);
 
 	this.width=paraselene_min(window.innerWidth,document.body.clientWidth);
 	this.width=paraselene_min(this.width,document.documentElement.clientWidth);
+	this.width=paraselene_min(this.width,document.body.scrollWidth);
 }
 
 function ParaseleneDocumentSize(){
@@ -358,9 +360,9 @@ function paraselene_back_kill(){
 	setTimeout(paraselene_back_kill,10);
 }
 
-function paraselene_back_kill_start(frg){
+function paraselene_back_kill_start(){
 	if(paraselene_back_kill_f)return;
-	document.location.href=document.location.href.split('#')[0]+"#"+frg;
+	document.location.href=document.location.href.split('#')[0]+"#paraselene";
 	paraselene_back_kill_f=true;
 	paraselene_back_kill();
 }
@@ -376,7 +378,7 @@ function paraselene_comet_callback(obj){
 
 function paraselene_comet_start(){
 	paraselene_comet_f=true;
-	paraselene_back_kill_start("");
+	paraselene_back_kill_start();
 	paraselene_ajax_entry2("paraselene_comet",paraselene_comet_callback,1,1);
 }
 
@@ -396,7 +398,7 @@ function paraselene_z_order(pop,del_f){
 		paraselene_remove(pop);
 		top=paraselene_popup.pop();
 		if(top){
-			top.className="paraselenePopupBase paraseleneTopOrder";
+			paraseleneClassZOrder(top,"paraseleneTopOrder");
 			paraselene_popup.push(top);
 		}
 		return;
@@ -406,7 +408,7 @@ function paraselene_z_order(pop,del_f){
 	}
 	if(pop==top)	return;
 	if(!del_f && top){
-		top.className="paraselenePopupBase paraseleneNextOrder";
+		paraseleneClassZOrder(top,"paraseleneNextOrder");
 	}
 
 	var des=new Array(0);
@@ -427,12 +429,12 @@ function paraselene_z_order(pop,del_f){
 		paraselene_remove(pop);
 		top=paraselene_popup.pop();
 		if(top){
-			top.className="paraselenePopupBase paraseleneTopOrder";
+			paraseleneClassZOrder(top,"paraseleneTopOrder");
 			paraselene_popup.push(top);
 		}
 		return;
 	}
-	pop.className="paraselenePopupBase paraseleneTopOrder";
+	paraseleneClassZOrder(pop,"paraseleneTopOrder");
 	pop.style.zIndex=last_z;
 	des.push(pop);
 }
@@ -481,41 +483,63 @@ function paraselene_dialog_open(dialog){
 	}
 	var base=document.createElement("div");
 	base.id=pageid;
-	base.className="paraselenePopupBase paraseleneTopOrder";
 	base.style.zIndex=z;
-	base.style.background=dialog.bg2;
-	base.style.borderColor=dialog.border;
-
-	var head=document.createElement("div");
-	head.className="paraselenePopupHead paraseleneGradient";
-	head.style.borderColor=dialog.border;
-
-	var a=document.createElement("span");
-	a.className="paraselenePopupHead";
-	a.innerHTML=dialog.title;
-	head.appendChild(a);
 
 	var body=document.createElement("div");
 	body.id=dialog.id;
-	body.className="paraselenePopupBody";
 	body.style.background=dialog.bg;
-	body.style.borderColor=dialog.border;
 	body.innerHTML=dialog.body;
+	if(dialog.move==true){
+		base.className="paraselenePopupBase paraseleneTopOrder";
+		base.style.borderColor=dialog.border;
+		base.style.background=dialog.bg2;
 
-	base.appendChild(head);
+		var head=document.createElement("div");
+		head.className="paraselenePopupHead paraseleneGradient";
+		head.style.borderColor=dialog.border;
+
+		var a=document.createElement("span");
+		a.className="paraselenePopupHead";
+		a.innerHTML=dialog.title;
+		head.appendChild(a);
+
+		body.className="paraselenePopupBody";
+		body.style.borderColor=dialog.border;
+
+		base.appendChild(head);
+	}
+	else{
+		base.className="paraseleneLiteBase paraseleneTopOrder";
+		base.style.background=dialog.bg;
+	}
 	base.appendChild(body);
 
 	var top=paraselene_popup.pop();
 	if(top){
-		top.className="paraselenePopupBase paraseleneNextOrder";
+		paraseleneClassZOrder(top,"paraseleneNextOrder");
 		paraselene_popup.push(top);
 	}
 	paraselene_popup.push(base);
 
+	var size=new ParaseleneWindowSize();
 	point.appendChild(base);
-	paraselene_tag_center(base,paraselene_mous_up_x,paraselene_mous_up_y);
-	paraselene_back_kill_start(pageid);
-	paraselene_dialog_set_event(base,head);
+	if(dialog.move==true){
+		paraselene_tag_center(base,paraselene_mous_up_x,paraselene_mous_up_y);
+		paraselene_dialog_set_event(base,head);
+	}
+	else{
+		paraselene_tag_center(base,size.width/2,size.height/2);
+	}
+	paraselene_back_kill_start();
+}
+
+function paraseleneClassZOrder(tag,n){
+	var org=tag.className.split(" ");
+	tag.className=n;
+	for(var i=0;i<org.length;i++){
+		if(org[i]=="paraseleneTopOrder"||org[i]=="paraseleneNextOrder")	continue;
+		tag.className=tag.className+" "+org[i];
+	}
 }
 
 function paraselene_action(obj){
