@@ -185,6 +185,7 @@ public abstract class Page implements Serializable {
 	private ArrayList<PageBypassedDiv>	bypass = new ArrayList<PageBypassedDiv>();
 	private ArrayList<PageHooker>	hook = new ArrayList<PageHooker>();
 	private ArrayList<Clickable>	clickable = new ArrayList<Clickable>();
+	private Page	parent_page = null;
 
 	private int name_seq = 0;
 	private Tag	contents = null;
@@ -200,6 +201,23 @@ public abstract class Page implements Serializable {
 	private static final Object	obj4uniKey = new Object();
 	private String uniKey;
 
+	/**
+	 * 親ページの取得。
+	 * @return 親ページ、もしくは this を返す。
+	 */
+	public Page getParentPage() {
+		if ( parent_page == null )	return this;
+		return parent_page.getParentPage();
+	}
+
+	/**
+	 * 親ページの設定
+	 * @param p 親ページ。
+	 */
+	public void setParentPage( Page p ) {
+		parent_page = p;
+	}
+
 	/**
 	 * 保持している PageBypassedDiv を返します。
 	 * @return PageBypassedDivの配列。無ければ 0 個の配列を返します。
