@@ -1,6 +1,6 @@
 /*
  * Paraselene
- * Copyright (c) 2009  Akira Terasaki
+ * Copyright (c) 2009, 2010  Akira Terasaki
  * このファイルは同梱されているLicense.txtに定めた条件に同意できる場合にのみ
  * 利用可能です。
  */
@@ -96,7 +96,7 @@ public class Property implements Serializable {
 	 * @param n 属性名。
 	 * @param v 属性値。
 	 */
-	public Property( boolean important, String n, Valuable ... v ) {
+	public Property( boolean important, String n, CSSValuable ... v ) {
 		setImportant( important );
 		setName( n );
 		set( v );
@@ -108,7 +108,7 @@ public class Property implements Serializable {
 	 * @param n 属性名。
 	 * @param v 属性値。
 	 */
-	public Property( String n, Valuable ... v ) {
+	public Property( String n, CSSValuable ... v ) {
 		this( false, n, v );
 	}
 
@@ -182,7 +182,7 @@ public class Property implements Serializable {
 	 * 属性値の設定。
 	 * @param v 属性値。
 	 */
-	public void set( Valuable ... v ) {
+	public void set( CSSValuable ... v ) {
 		value = Converter.toCSSValuable( v );
 		embed_tag.setModify();
 	}
