@@ -32,8 +32,8 @@ public class Feedback extends Forward implements AjaxForward {
 	 * @param page 更新対象。
 	 */
 	public Feedback( Page page ) {
-		super( page.getID() );
-		target = page;
+		super( page.getParentPage().getID() );
+		target = page.getParentPage();
 	}
 
 	Page getPage( Page from ) {
