@@ -123,11 +123,8 @@ public class Forward implements Serializable {
 		if ( hist == null )	return null;
 		Page[]	page = hist.getBrowsingPage();
 		Popup.Type	ptype = Popup.Type.MODELESS;
-		for ( int i = 0; i < page.length; i++ ) {
-			if ( page[i].getPopupType() == Popup.Type.MODAL ) {
-				ptype = Popup.Type.MODAL;
-				break;
-			}
+		if ( Popup.isModelessAlert( ptype, hist, false ) ) {
+			ptype = Popup.Type.MODAL;
 		}
 		ArrayList<AjaxForward>	list = new ArrayList<AjaxForward>();
 		for ( int i = 0; i < af.length - 1; i++ ) {
