@@ -1,6 +1,6 @@
 /*
  * Paraselene
- * Copyright (c) 2009  Akira Terasaki
+ * Copyright (c) 2009, 2010  Akira Terasaki
  * このファイルは同梱されているLicense.txtに定めた条件に同意できる場合にのみ
  * 利用可能です。
  */
@@ -57,12 +57,31 @@ public class History implements Serializable {
 		session_id = s;
 	}
 
-	private boolean addPopup( Page page ) {
-		if ( page.getPopupType() == null )	return false;
+	/**
+	 * サテライトページ追加。
+	 * @param page 追加ページ。
+	 */
+	public void addSatellitePage( Page page ) {
+		if ( page == null )	return;
 		synchronized( popup ) {
 			removePopup( page );
 			popup.add( page );
 		}
+		Option.trace( "addSatellitePage %d %s", hashCode(), page.getUniqueKey() );
+	}
+
+	/**
+	 * サテライトページ削除。
+	 * @param page 削除ページ。
+	 */
+	public void removeSatellitePage( Page page ) {
+		if ( page == null )	return;
+		removePopup( page );
+	}
+
+	private boolean addPopup( Page page ) {
+		if ( page.getPopupType() == null )	return false;
+		addSatellitePage( page );
 		return true;
 	}
 
@@ -73,6 +92,7 @@ public class History implements Serializable {
 			for ( int i = 0; i < cnt; i++ ) {
 				if ( popup.get( i ).getUniqueKey().equals( key ) ) {
 					popup.remove( i );
+					Option.trace( "removePopup %s", key );
 					return;
 				}
 			}
@@ -83,7 +103,7 @@ public class History implements Serializable {
 	private void clearPopup() {
 		synchronized( popup ) {
 			popup.clear();
-			Option.trace( "popup clear" );
+			Option.traceWithStack( "popup clear" );
 		}
 	}
 
@@ -176,11 +196,13 @@ public class History implements Serializable {
 	 * @return 一致したページ。
 	 */
 	public Page getBrowsingPage( String uni ) {
+		Option.trace( "getBrowsingPage  %d >> %s", hashCode(), uni );
 		Page	page = null;
 		synchronized( popup ) {
 			int cnt = popup.size();
 			for ( int i = 0; i < cnt; i++ ){
 				page = popup.get( i );
+				Option.trace( "getBrowsingPage popup %d %s", hashCode(), page.getUniqueKey() );
 				if ( page.getUniqueKey().equals( uni ) )	return page;
 			}
 		}
