@@ -114,21 +114,14 @@ class OpenOutput extends OutputCall {
 				h.unlock();
 			}
 		}
-		if ( p.active_page.getPopupType() != Popup.Type.MODELESS )	return new PostBack[0];
-		try {
-			Page[]	page = h.getBrowsingPage();
-			for ( int i = 0; i < page.length; i++ ) {
-				if ( page[i].getPopupType() == Popup.Type.MODAL ) {
-					Option.trace( "%s/%s to Popup active cancel, because MODAL opened", next_page.getID(), next_page.getUniqueKey() );
-					return new PostBack[0];
-				}
-			}
-			Option.trace( "%s/%s to Popup active JSON", next_page.getID(), next_page.getUniqueKey() );
-			return new PostBack[] { new PostBack( new Open( p.active_page, true ) ) };
-		}
-		finally {
-			h.unlock();
+		Popup.Type	ptype = p.active_page.getPopupType();
+		if ( Popup.isModeless( ptype ) )	return new PostBack[0];
+		if ( Popup.isModelessAlert( ptype, h, true ) ) {
+			Option.trace( "%s/%s to Popup active cancel, because MODAL opened", next_page.getID(), next_page.getUniqueKey() );
+			return new PostBack[0];
 		}
+		Option.trace( "%s/%s to Popup active JSON", next_page.getID(), next_page.getUniqueKey() );
+		return new PostBack[] { new PostBack( new Open( p.active_page, true ) ) };
 	}
 }
 
