@@ -155,7 +155,9 @@ class Child extends Thread implements DaemonChannel {
 		if ( page == null )	return fw;
 		PageHooker[]	hook = sort( page.getPageHooker() );
 		for ( int i = 0; i < hook.length; i++ ) {
+			Forward	old = fw;
 			fw = hook[i].beforeInput( page, req, fw );
+			if ( fw == null )	fw = old;
 		}
 		return page.input( req, fw );
 	}
