@@ -20,6 +20,21 @@ import java.util.*;
 public class Anchor extends Tag implements PageHooker, Clickable {
 	private static final long serialVersionUID = 2L;
 	private static final String	ANCHOR_ID = "paraselene$anchor$id";
+	private static final String	ANCHOR_URL_ID = "paraselene$anchor$dummy";
+
+	private boolean fix_id_f = false;
+	private static byte seq = 0;
+
+	private static String make_id() {
+		long d = 0;
+		synchronized( ANCHOR_ID ) {
+			seq++;
+			d = seq;
+		}
+		d <<= 56;
+		d |= (new Date().getTime() & 0x00ffffffffffffffL);
+		return Long.toString( d, Character.MAX_RADIX );
+	}
 
 	/**
 	 * コンストラクタ。
@@ -28,6 +43,22 @@ public class Anchor extends Tag implements PageHooker, Clickable {
 		super( "a", false );
 	}
 
+	/**
+	 * URL固定指定。デフォルト false です。
+	 * @param flag true:固定にする、false:毎回変更する。
+	 */
+	public void setFixedURL( boolean flag ) {
+		fix_id_f = flag;
+	}
+
+	/**
+	 * URL固定状態の取得。デフォルト false です。
+	 * @return true:固定にする、false:毎回変更する。
+	 */
+	public boolean isFixedURL() {
+		return fix_id_f;
+	}
+
 	protected Tag newReplica() {
 		Anchor	a = new Anchor();
 		a.setUserData( getUserData() );
@@ -59,6 +90,9 @@ public class Anchor extends Tag implements PageHooker, Clickable {
 				list.add( item[i] );
 			}
 			list.add( new QueryItem( Form.PAGE_UKEY, getAssignedPage().getUniqueKey() ) );
+			if ( !fix_id_f ) {
+				list.add( new QueryItem( ANCHOR_URL_ID, make_id() ) );
+			}
 			list.add( new QueryItem( ANCHOR_ID, id ) );
 			uv.setQuery( list.toArray( new QueryItem[0] ) );
 		}
