@@ -352,6 +352,21 @@ public class Form extends Tag implements PageHooker {
 				set.add( now );
 			}
 		}
+
+		int	cnt = set.size();
+		HashMap<RadioGroup, RadioGroup>	radio = new HashMap<RadioGroup, RadioGroup>();
+		for ( int i = cnt - 1; i >= 0; i-- ) {
+			Control	c = set.get( i );
+			if ( !(c instanceof CheckBox) )	continue;
+			CheckBox	cb = (CheckBox)c;
+			RadioGroup	gr = cb.getRadioGroup();
+			if ( gr == null )	continue;
+			radio.put( gr, gr );
+			set.remove( i );
+		}
+		for ( RadioGroup gr: radio.keySet() ) {
+			set.add( gr );
+		}
 		return set;
 	}
 
