@@ -1,6 +1,6 @@
 /*
  * Paraselene
- * Copyright (c) 2009  Akira Terasaki
+ * Copyright (c) 2009, 2010  Akira Terasaki
  * このファイルは同梱されている License.txt に定めた条件に同意できる場合にのみ
  * 利用可能です。
  */
@@ -71,6 +71,9 @@ public class CssTool {
 					bw.write( "\\\"" );
 				}
 				else if ( ch[i] == '\t' )	continue;
+				else if ( ch[i] == '\\' ) {
+					bw.write( "\\\\" );
+				}
 				else {
 					bw.write( ch[i] );
 				}
